group = "com.trafficparrot"
version = "5.29.3"

plugins {
    java
    id("com.trafficparrot").version("5.29.3")
}

repositories {
    mavenCentral()
    mavenLocal()
    maven("https://trafficparrot.com/repository")
}

dependencies {
    testCompile("javax.jms", "javax.jms-api", "2.0.1")
    testCompile("org.apache.activemq", "activemq-client", "5.14.5")
    testCompile("org.apache.httpcomponents", "httpclient", "4.5.2")
    testCompile("org.slf4j", "slf4j-simple", "1.7.30")
    testCompile("commons-io", "commons-io", "2.8.0")
    testCompile("junit", "junit", "4.13.2")
    testCompile("org.assertj", "assertj-core", "3.19.0")
    testCompile("org.json", "json", "20180813")
    testCompile("org.xmlunit", "xmlunit-assertj", "2.8.2")
    testCompile("net.bytebuddy", "byte-buddy", "1.10.22")
}

configure<JavaPluginConvention> {
    sourceCompatibility = JavaVersion.VERSION_1_8
    targetCompatibility = JavaVersion.VERSION_1_8
}

startTrafficParrot {
    // This can either be a file("C:\some\path\to\trafficparrot-no-jre-5.6.0.zip").toURL()
    // or a URL("https://your-server/trafficparrot-no-jre-5.6.0.zip") location of the Traffic Parrot release ZIP file
    downloadFrom = file("C:\some\path\to\trafficparrot-no-jre-5.29.3.zip").toURL()

    // Set this to true to indicate that you accept the Traffic Parrot LICENSE terms
    acceptLicense = false

    // Set this to true if you would like to cache the download in the java.io.tmpdir
    cacheDownload = false

    // Set this to the location of your Traffic Parrot enterprise license file
    licenseFile = file("/path/to/trafficparrot.license").toURL()

    trafficFilesRoot = file(project.projectDir.absolutePath + "/src/test/resources/trafficparrot")

    // This will import Swagger/OpenAPI/RAML specifications
    httpImportMappings = true

    httpVirtualServicePort = 18081
    httpsVirtualServicePort = 18082

    jmsConnectionsFile = file(project.projectDir.absolutePath + "/src/test/resources/trafficparrot/jms-connections.json").toURL()

    jmsBrokerType = "INTERNAL"
    jmsInternalBrokerPort = 19091
    jmsInternalBrokerProvider = "ACTIVE_MQ"
    jmsReplayQueue = true
    jmsQueueConsumeRequestsFromConnectionId = "USE-TRAFFIC-PARROT-INTERNAL-BROKER"
    jmsQueueReplayResponsesToConnectionId = "example-connection-id"
    jmsReplayTopic = true
    jmsTopicReplayToConnectionId = "example-connection-id"
}

stopTrafficParrot {
    deleteAfterStop = true
}

buildscript {
    configurations.getByName("classpath") {
        resolutionStrategy.cacheChangingModulesFor(0, TimeUnit.SECONDS)
    }
}